@@ -35,6 +35,7 @@ from agent_cli.core.utils import (
     format_timedelta_to_ago,
     live_timer,
     maybe_live,
+    print_command_line_args,
     print_input_panel,
     print_output_panel,
     print_with_style,
@@ -157,21 +158,21 @@ async def _handle_conversation_turn(
     openai_asr_cfg: config.OpenAIASR,
     ollama_cfg: config.Ollama,
     openai_llm_cfg: config.OpenAILLM,
+    gemini_llm_cfg: config.GeminiLLM,
     audio_out_cfg: config.AudioOutput,
     wyoming_tts_cfg: config.WyomingTTS,
     openai_tts_cfg: config.OpenAITTS,
-    kokoro_tts_config: config.KokoroTTS,
+    kokoro_tts_cfg: config.KokoroTTS,
     live: Live,
 ) -> None:
     """Handles a single turn of the conversation."""
     # 1. Transcribe user's command
     start_time = time.monotonic()
-    transcriber = asr.get_transcriber(
+    transcriber = asr.create_transcriber(
         provider_cfg,
         audio_in_cfg,
         wyoming_asr_cfg,
         openai_asr_cfg,
-        openai_llm_cfg,
     )
     instruction = await transcriber(
         p=p,
@@ -216,11 +217,12 @@ async def _handle_conversation_turn(
 
     start_time = time.monotonic()
 
-    model_name = (
-        ollama_cfg.ollama_model
-        if provider_cfg.llm_provider == "local"
-        else openai_llm_cfg.openai_llm_model
-    )
+    if provider_cfg.llm_provider == "local":
+        model_name = ollama_cfg.llm_ollama_model
+    elif provider_cfg.llm_provider == "openai":
+        model_name = openai_llm_cfg.llm_openai_model
+    elif provider_cfg.llm_provider == "gemini":
+        model_name = gemini_llm_cfg.llm_gemini_model
     async with live_timer(
         live,
         f"🤖 Processing with {model_name}",
@@ -232,9 +234,10 @@ async def _handle_conversation_turn(
             system_prompt=SYSTEM_PROMPT,
             agent_instructions=AGENT_INSTRUCTIONS,
             user_input=user_message_with_context,
-            provider_config=provider_cfg,
-            ollama_config=ollama_cfg,
-            openai_config=openai_llm_cfg,
+            provider_cfg=provider_cfg,
+            ollama_cfg=ollama_cfg,
+            openai_cfg=openai_llm_cfg,
+            gemini_cfg=gemini_llm_cfg,
             logger=LOGGER,
             tools=tools(),
             quiet=True,  # Suppress internal output since we're showing our own timer
@@ -277,12 +280,11 @@ async def _handle_conversation_turn(
     if audio_out_cfg.enable_tts:
         await handle_tts_playback(
             text=response_text,
-            provider_config=provider_cfg,
-            audio_output_config=audio_out_cfg,
-            wyoming_tts_config=wyoming_tts_cfg,
-            openai_tts_config=openai_tts_cfg,
-            openai_llm_config=openai_llm_cfg,
-            kokoro_tts_config=kokoro_tts_config,
+            provider_cfg=provider_cfg,
+            audio_output_cfg=audio_out_cfg,
+            wyoming_tts_cfg=wyoming_tts_cfg,
+            openai_tts_cfg=openai_tts_cfg,
+            kokoro_tts_cfg=kokoro_tts_cfg,
             save_file=general_cfg.save_file,
             quiet=general_cfg.quiet,
             logger=LOGGER,
@@ -308,10 +310,11 @@ async def _async_main(
     openai_asr_cfg: config.OpenAIASR,
     ollama_cfg: config.Ollama,
     openai_llm_cfg: config.OpenAILLM,
+    gemini_llm_cfg: config.GeminiLLM,
     audio_out_cfg: config.AudioOutput,
     wyoming_tts_cfg: config.WyomingTTS,
     openai_tts_cfg: config.OpenAITTS,
-    kokoro_tts_config: config.KokoroTTS,
+    kokoro_tts_cfg: config.KokoroTTS,
 ) -> None:
     """Main async function, consumes parsed arguments."""
     try:
@@ -354,10 +357,11 @@ async def _async_main(
                         openai_asr_cfg=openai_asr_cfg,
                         ollama_cfg=ollama_cfg,
                         openai_llm_cfg=openai_llm_cfg,
+                        gemini_llm_cfg=gemini_llm_cfg,
                         audio_out_cfg=audio_out_cfg,
                         wyoming_tts_cfg=wyoming_tts_cfg,
                         openai_tts_cfg=openai_tts_cfg,
-                        kokoro_tts_config=kokoro_tts_config,
+                        kokoro_tts_cfg=kokoro_tts_cfg,
                         live=live,
                     )
     except Exception:
@@ -376,29 +380,31 @@ def chat(
     # --- ASR (Audio) Configuration ---
     input_device_index: int | None = opts.INPUT_DEVICE_INDEX,
     input_device_name: str | None = opts.INPUT_DEVICE_NAME,
-    wyoming_asr_ip: str = opts.WYOMING_ASR_SERVER_IP,
-    wyoming_asr_port: int = opts.WYOMING_ASR_SERVER_PORT,
-    openai_asr_model: str = opts.OPENAI_ASR_MODEL,
+    asr_wyoming_ip: str = opts.ASR_WYOMING_IP,
+    asr_wyoming_port: int = opts.ASR_WYOMING_PORT,
+    asr_openai_model: str = opts.ASR_OPENAI_MODEL,
     # --- LLM Configuration ---
-    ollama_model: str = opts.OLLAMA_MODEL,
-    ollama_host: str = opts.OLLAMA_HOST,
-    openai_llm_model: str = opts.OPENAI_LLM_MODEL,
+    llm_ollama_model: str = opts.LLM_OLLAMA_MODEL,
+    llm_ollama_host: str = opts.LLM_OLLAMA_HOST,
+    llm_openai_model: str = opts.LLM_OPENAI_MODEL,
     openai_api_key: str | None = opts.OPENAI_API_KEY,
+    llm_gemini_model: str = opts.LLM_GEMINI_MODEL,
+    gemini_api_key: str | None = opts.GEMINI_API_KEY,
     # --- TTS Configuration ---
     enable_tts: bool = opts.ENABLE_TTS,
     output_device_index: int | None = opts.OUTPUT_DEVICE_INDEX,
     output_device_name: str | None = opts.OUTPUT_DEVICE_NAME,
     tts_speed: float = opts.TTS_SPEED,
-    wyoming_tts_ip: str = opts.WYOMING_TTS_SERVER_IP,
-    wyoming_tts_port: int = opts.WYOMING_TTS_SERVER_PORT,
-    wyoming_voice: str | None = opts.WYOMING_VOICE_NAME,
-    wyoming_tts_language: str | None = opts.WYOMING_TTS_LANGUAGE,
-    wyoming_speaker: str | None = opts.WYOMING_SPEAKER,
-    openai_tts_model: str = opts.OPENAI_TTS_MODEL,
-    openai_tts_voice: str = opts.OPENAI_TTS_VOICE,
-    kokoro_tts_model: str = opts.KOKORO_TTS_MODEL,
-    kokoro_tts_voice: str = opts.KOKORO_TTS_VOICE,
-    kokoro_tts_host: str = opts.KOKORO_TTS_HOST,
+    tts_wyoming_ip: str = opts.TTS_WYOMING_IP,
+    tts_wyoming_port: int = opts.TTS_WYOMING_PORT,
+    tts_wyoming_voice: str | None = opts.TTS_WYOMING_VOICE,
+    tts_wyoming_language: str | None = opts.TTS_WYOMING_LANGUAGE,
+    tts_wyoming_speaker: str | None = opts.TTS_WYOMING_SPEAKER,
+    tts_openai_model: str = opts.TTS_OPENAI_MODEL,
+    tts_openai_voice: str = opts.TTS_OPENAI_VOICE,
+    tts_kokoro_model: str = opts.TTS_KOKORO_MODEL,
+    tts_kokoro_voice: str = opts.TTS_KOKORO_VOICE,
+    tts_kokoro_host: str = opts.TTS_KOKORO_HOST,
     # --- Process Management ---
     stop: bool = opts.STOP,
     status: bool = opts.STATUS,
@@ -423,9 +429,12 @@ def chat(
     log_file: str | None = opts.LOG_FILE,
     list_devices: bool = opts.LIST_DEVICES,
     quiet: bool = opts.QUIET,
-    config_file: str | None = opts.CONFIG_FILE,  # noqa: ARG001
+    config_file: str | None = opts.CONFIG_FILE,
+    print_args: bool = opts.PRINT_ARGS,
 ) -> None:
     """An chat agent that you can talk to."""
+    if print_args:
+        print_command_line_args(locals())
     setup_logging(log_level, log_file, quiet=quiet)
     general_cfg = config.General(
         log_level=log_level,
@@ -457,15 +466,25 @@ def chat(
             input_device_name=input_device_name,
         )
         wyoming_asr_cfg = config.WyomingASR(
-            wyoming_asr_ip=wyoming_asr_ip,
-            wyoming_asr_port=wyoming_asr_port,
+            asr_wyoming_ip=asr_wyoming_ip,
+            asr_wyoming_port=asr_wyoming_port,
         )
-        openai_asr_cfg = config.OpenAIASR(openai_asr_model=openai_asr_model)
-        ollama_cfg = config.Ollama(ollama_model=ollama_model, ollama_host=ollama_host)
-        openai_llm_cfg = config.OpenAILLM(
-            openai_llm_model=openai_llm_model,
+        openai_asr_cfg = config.OpenAIASR(
+            asr_openai_model=asr_openai_model,
             openai_api_key=openai_api_key,
         )
+        ollama_cfg = config.Ollama(
+            llm_ollama_model=llm_ollama_model,
+            llm_ollama_host=llm_ollama_host,
+        )
+        openai_llm_cfg = config.OpenAILLM(
+            llm_openai_model=llm_openai_model,
+            openai_api_key=openai_api_key,
+        )
+        gemini_llm_cfg = config.GeminiLLM(
+            llm_gemini_model=llm_gemini_model,
+            gemini_api_key=gemini_api_key,
+        )
         audio_out_cfg = config.AudioOutput(
             enable_tts=enable_tts,
             output_device_index=output_device_index,
@@ -473,20 +492,21 @@ def chat(
             tts_speed=tts_speed,
         )
         wyoming_tts_cfg = config.WyomingTTS(
-            wyoming_tts_ip=wyoming_tts_ip,
-            wyoming_tts_port=wyoming_tts_port,
-            wyoming_voice=wyoming_voice,
-            wyoming_tts_language=wyoming_tts_language,
-            wyoming_speaker=wyoming_speaker,
+            tts_wyoming_ip=tts_wyoming_ip,
+            tts_wyoming_port=tts_wyoming_port,
+            tts_wyoming_voice=tts_wyoming_voice,
+            tts_wyoming_language=tts_wyoming_language,
+            tts_wyoming_speaker=tts_wyoming_speaker,
         )
         openai_tts_cfg = config.OpenAITTS(
-            openai_tts_model=openai_tts_model,
-            openai_tts_voice=openai_tts_voice,
+            tts_openai_model=tts_openai_model,
+            tts_openai_voice=tts_openai_voice,
+            openai_api_key=openai_api_key,
         )
         kokoro_tts_cfg = config.KokoroTTS(
-            kokoro_tts_model=kokoro_tts_model,
-            kokoro_tts_voice=kokoro_tts_voice,
-            kokoro_tts_host=kokoro_tts_host,
+            tts_kokoro_model=tts_kokoro_model,
+            tts_kokoro_voice=tts_kokoro_voice,
+            tts_kokoro_host=tts_kokoro_host,
         )
         history_cfg = config.History(
             history_dir=history_dir,
@@ -503,9 +523,10 @@ def chat(
                 openai_asr_cfg=openai_asr_cfg,
                 ollama_cfg=ollama_cfg,
                 openai_llm_cfg=openai_llm_cfg,
+                gemini_llm_cfg=gemini_llm_cfg,
                 audio_out_cfg=audio_out_cfg,
                 wyoming_tts_cfg=wyoming_tts_cfg,
                 openai_tts_cfg=openai_tts_cfg,
-                kokoro_tts_config=kokoro_tts_cfg,
+                kokoro_tts_cfg=kokoro_tts_cfg,
             ),
         )
